Module google

Module google 

Google Rich Results profiles.

Implements validation for 7 Schema.org types that Google supports for rich result display in Search.

Structs

GoogleArticleProfile
Google Rich Results profile for Article structured data.
GoogleBreadcrumbProfile
Google Rich Results profile for BreadcrumbList structured data.
GoogleEventProfile
Google Rich Results profile for Event structured data.
GoogleFaqPageProfile
Google Rich Results profile for FAQPage structured data.
GoogleLocalBusinessProfile
Google Rich Results profile for LocalBusiness structured data.
GoogleProductProfile
Google Rich Results profile for Product structured data.
GoogleRecipeProfile
Google Rich Results profile for Recipe structured data.

Functions

register_all
Registers all Google Rich Results profiles in the given registry.