Google Rich Results profiles.
Implements validation for 7 Schema.org types that Google supports for rich result display in Search.
Structs
- Google
Article Profile - Google Rich Results profile for Article structured data.
- Google
Breadcrumb Profile - Google Rich Results profile for
BreadcrumbListstructured data. - Google
Event Profile - Google Rich Results profile for Event structured data.
- Google
FaqPage Profile - Google Rich Results profile for
FAQPagestructured data. - Google
Local Business Profile - Google Rich Results profile for
LocalBusinessstructured data. - Google
Product Profile - Google Rich Results profile for Product structured data.
- Google
Recipe Profile - Google Rich Results profile for Recipe structured data.
Functions
- register_
all - Registers all Google Rich Results profiles in the given registry.